# Security Policy

## Supported Versions

Security fixes are prioritized for the latest version on the default branch.

## Reporting a Vulnerability

Please do not open public issues for security vulnerabilities.

Instead, report privately by email:

- marklubin@pm.me

Include:

- a description of the issue
- steps to reproduce
- potential impact
- any suggested mitigation

We will acknowledge receipt and provide status updates as we investigate.
